DockStyle class
Resolved style (colors are final values)
Constructors
- DockStyle({required Color background, required Color surface, required Color surface2, required Color border, required Color text, required Color accent, required Color shadow, required double shadowOpacity, required Color overlayButtonBg, required Color overlayButtonSelectedBg, required Color overlayIcon, required Color stripButtonHover, required Color splitterHighlight, double autoHideGap = IDETheme.autoHideGap, double stripThickness = IDETheme.stripThickness, double tabbarHeight = IDETheme.tabbarHeight, double floatTitleBarHeight = IDETheme.floatTitleBarHeight, double guideButtonSize = IDETheme.guideButtonSize, double guideButtonPadding = IDETheme.guideButtonPadding, double resizeGripSize = IDETheme.resizeGripSize, double cornerRadius = IDETheme.cornerRadius, double shadowBlur = IDETheme.shadowBlur, double shadowSpread = IDETheme.shadowSpread, double floatDefaultWidth = IDETheme.floatDefaultWidth, double floatDefaultHeight = IDETheme.floatDefaultHeight, double floatTitleGrabOffset = IDETheme.floatTitleGrabOffset, double floatScreenPad = IDETheme.floatScreenPad, double floatMinVisibleX = IDETheme.floatMinVisibleX, double floatMinVisibleY = IDETheme.floatMinVisibleY, double floatMinWidth = IDETheme.floatMinWidth, double floatMinHeight = IDETheme.floatMinHeight, double floatMaxWidth = IDETheme.floatMaxWidth, double floatMaxHeight = IDETheme.floatMaxHeight, EdgeInsets stripButtonPadding = const EdgeInsets.symmetric(horizontal: 15, vertical: 6), IconData iconClose = FluentIcons.chrome_close, IconData iconPin = FluentIcons.pin, IconData iconFloatTitle = FluentIcons.edit, IconData iconResizeGrip = WindowsIcons.resize_mouse_medium, double flyoutAnimationOffset = 28.0, double dragHoverBlurSigma = 6.0, double dragSourceBlurSigma = 2.0, int dragBlurMs = 120, IconData maximizeIcon = WindowsIcons.chrome_maximize, IconData minimizeIcone = WindowsIcons.chrome_restore, Color iconColorBlueBg = Colors.white})
-
const
- DockStyle.fromTheme(BuildContext context)
-
Build a style based on current FluentTheme (auto light/dark).
factory
Properties
- accent → Color
-
final
- autoHideGap → double
-
final
- background → Color
-
final
- border → Color
-
final
- cornerRadius → double
-
final
- dragBlurMs → int
-
final
- dragHoverBlurSigma → double
-
final
- dragSourceBlurSigma → double
-
final
- floatDefaultHeight → double
-
final
- floatDefaultWidth → double
-
final
- floatMaxHeight → double
-
final
- floatMaxWidth → double
-
final
- floatMinHeight → double
-
final
- floatMinVisibleX → double
-
final
- floatMinVisibleY → double
-
final
- floatMinWidth → double
-
final
- floatScreenPad → double
-
final
- floatTitleBarHeight → double
-
final
- floatTitleGrabOffset → double
-
final
- flyoutAnimationOffset → double
-
final
- guideButtonPadding → double
-
final
- guideButtonSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconClose → IconData
-
final
- iconColorBlueBg → Color
-
final
- iconFloatTitle → IconData
-
final
- iconPin → IconData
-
final
- iconResizeGrip → IconData
-
final
- maximizeIcon → IconData
-
final
- minimizeIcone → IconData
-
final
- overlayButtonBg → Color
-
final
- overlayButtonSelectedBg → Color
-
final
- overlayIcon → Color
-
final
- resizeGripSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → Color
-
final
- shadowBlur → double
-
final
- shadowOpacity → double
-
final
- shadowSpread → double
-
final
- splitterHighlight → Color
-
final
- stripButtonHover → Color
-
final
- stripButtonPadding → EdgeInsets
-
final
- stripThickness → double
-
final
- surface → Color
-
final
- surface2 → Color
-
final
- tabbarHeight → double
-
final
- text → Color
-
final
Methods
-
copyWith(
{Color? background, Color? surface, Color? surface2, Color? border, Color? text, Color? accent, Color? shadow, double? shadowOpacity, Color? overlayButtonBg, Color? overlayButtonSelectedBg, Color? overlayIcon, Color? stripButtonHover, Color? splitterHighlight, double? dragHoverBlurSigma, double? dragSourceBlurSigma, int? dragBlurMs}) → DockStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultStyle(
) → DockStyle - Default style for backward compatibility