IDETheme class
Constructors
- IDETheme()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accent → const Color
- autoHideGap → const double
- cornerRadius → const double
- edgeSnapBand → const double
- floatDefaultHeight → const double
- floatDefaultWidth → const double
- floatMaxHeight → const double
- floatMaxWidth → const double
- floatMinHeight → const double
- floatMinVisibleX → const double
- floatMinVisibleY → const double
- floatMinWidth → const double
- floatScreenPad → const double
- floatTitleBarHeight → const double
- floatTitleGrabOffset → const double
- guideButtonPadding → const double
- guideButtonSize → const double
- resizeGripSize → const double
- shadowBlur → const double
- shadowOpacity → const double
- shadowSpread → const double
- stripThickness → const double
- tabbarHeight → const double