AutoHideFlyout class

Inheritance

Constructors

AutoHideFlyout({Key? key, required AutoSide side, required String panelId, required String title, required Widget content, required double initialExtent, ValueChanged<double>? onExtentChanged, required void onPin(AutoSide side, String id), required void onClose(), required void onRemove(String panelId), required void onDragStart(Offset globalStart, String panelId), required void onDragUpdate(Offset globalPos), required VoidCallback onDragEnd, required DockStyle style})
const

Properties

content Widget
final
hashCode int
The hash code for this object.
no setterinherited
initialExtent double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose → void Function()
final
onDragEnd → void Function()
final
onDragStart → void Function(Offset globalStart, String panelId)
final
onDragUpdate → void Function(Offset globalPos)
final
onExtentChanged ValueChanged<double>?
final
onPin → void Function(AutoSide side, String id)
final
onRemove → void Function(String panelId)
final
panelId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side AutoSide
final
style DockStyle
final
title String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AutoHideFlyout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited