TabsContainer class

Inheritance

Constructors

TabsContainer({Key? key, required ContainerNode node, required DockPanelRegistry registry, required DockStyle style, void onClose(int index)?, required void onAutoHide(String panelId), required void onFloatRequest(String panelId, Offset start), required void onDragStart(String panelId, Offset start), required void onDragUpdate(Offset globalPos), required VoidCallback onDragEnd, required bool isMaximized, VoidCallback? onToggleMaximize, bool hideTabBar = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hideTabBar bool
final
isMaximized bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
node ContainerNode
final
onAutoHide → void Function(String panelId)
final
onClose → void Function(int index)?
final
onDragEnd VoidCallback
final
onDragStart → void Function(String panelId, Offset start)
final
onDragUpdate → void Function(Offset globalPos)
final
onFloatRequest → void Function(String panelId, Offset start)
final
onToggleMaximize VoidCallback?
final
registry DockPanelRegistry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style DockStyle
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TabsContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited